pub enum PlaygroundViewsMessage {
TimedOut,
Registered(Uuid),
ExerciseTaskGradingResult(ExerciseTaskGradingResult),
}Expand description
The message type for all messages sent from the server to the client from the playgrounds-views websocket connection.
Variants
TimedOut
Server did not receive a pong for a certain period so the connection timed out.
Registered(Uuid)
Server accepted a new websocket connection and is informing the new client of their connection id.
ExerciseTaskGradingResult(ExerciseTaskGradingResult)
Server received an updated grading from an exercise service and is passing it on to the client.